"""
This type stub file was generated by pyright.
"""

from ._common import *
from ._exif import *

TIFF_HEADER_LENGTH = ...
def dump(exif_dict_original): # -> bytes:
    """
    py:function:: piexif.load(data)

    Return exif as bytes.

    :param dict exif: Exif data({"0th":dict, "Exif":dict, "GPS":dict, "Interop":dict, "1st":dict, "thumbnail":bytes})
    :return: Exif
    :rtype: bytes
    """
    ...
