"""
This type stub file was generated by pyright.
"""

from ._common import *

def transplant(exif_src, image, new_file=...): # -> None:
    """
    py:function:: piexif.transplant(filename1, filename2)

    Transplant exif from filename1 to filename2.

    :param str filename1: JPEG
    :param str filename2: JPEG
    """
    ...
