"""
This type stub file was generated by pyright.
"""

from ._common import *
from ._exif import *

LITTLE_ENDIAN = ...
def load(input_data, key_is_name=...): # -> dict[str, Any]:
    """
    py:function:: piexif.load(filename)

    Return exif data as dict. Keys(IFD name), be contained, are "0th", "Exif", "GPS", "Interop", "1st", and "thumbnail". Without "thumbnail", the value is dict(tag name/tag value). "thumbnail" value is JPEG as bytes.

    :param str filename: JPEG or TIFF
    :return: Exif data({"0th":dict, "Exif":dict, "GPS":dict, "Interop":dict, "1st":dict, "thumbnail":bytes})
    :rtype: dict
    """
    ...

class _ExifReader:
    def __init__(self, data) -> None:
        ...

    def get_ifd_dict(self, pointer, ifd_name, read_unknown=...): # -> dict[Any, Any]:
        ...

    def convert_value(self, val): # -> Any | tuple[Any, Any] | bytes | tuple[Any, ...] | tuple[tuple[Any, Any], ...]:
        ...
